@@ -224,7 +224,7 @@ class rcube
             $this->caches[$name] = rcube_cache::factory($type, $userid, $name, $ttl, $packed, $indexed);
         }
 
-        return $this->caches[$name];
+        return $this->caches[$name] ?? null;
     }
 
     /**
@@ -942,7 +942,8 @@ class rcube
      */
     public function decrypt($cipher, $key = 'des_key', $base64 = true)
     {
-        if (strlen($cipher) == 0) {
+        // @phpstan-ignore-next-line
+        if (!is_string($cipher) || !strlen($cipher)) {
             return false;
         }
 
